==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/table.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	table.lang.inc.php 2018-04-09 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_SHIPPING_TABLE_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, in welche ein Versand möglich sein soll. (z.B. AT,DE (lassen Sie dieses Feld leer, wenn Sie alle Zonen erlauben wollen))',
	'MODULE_SHIPPING_TABLE_ALLOWED_TITLE' => 'Erlaubte Versandzonen',
	'MODULE_SHIPPING_TABLE_COST_DESC' => 'Die Versandkosten basieren auf Gesamtkosten oder Gesamtgewicht der bestellten Waren. Beispiel: 25:5.50,50:8.50,etc.. Bis 25 werden 5.50 verrechnet, darüber bis 50 werden 8.50 verrechnet, etc',
	'MODULE_SHIPPING_TABLE_COST_TITLE' => 'Versandkosten',
	'MODULE_SHIPPING_TABLE_HANDLING_DESC' => 'Handling Gebühr für diese Versandmethode',
	'MODULE_SHIPPING_TABLE_HANDLING_TITLE' => 'Handling Gebühr',
	'MODULE_SHIPPING_TABLE_MODE_DESC' => 'Die Versandkosten basieren auf Gesamtkosten oder Gesamtgewicht der bestellten Waren.',
	'MODULE_SHIPPING_TABLE_MODE_TITLE' => 'Versandkosten Methode',
	'MODULE_SHIPPING_TABLE_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige',
	'MODULE_SHIPPING_TABLE_SORT_ORDER_TITLE' => 'Sortierreihenfolge',
	'MODULE_SHIPPING_TABLE_STATUS_DESC' => 'Möchten Sie Versandkosten nach Preis/Gewicht anbieten?',
	'MODULE_SHIPPING_TABLE_STATUS_TITLE' => 'Versandkosten nach Preis/Gewicht aktivieren',
	'MODULE_SHIPPING_TABLE_TAX_CLASS_DESC' => 'Folgende Steuerklasse an Versandkosten anwenden',
	'MODULE_SHIPPING_TABLE_TAX_CLASS_TITLE' => 'Steuerklasse',
	'MODULE_SHIPPING_TABLE_TEXT_AMOUNT' => 'Menge',
	'MODULE_SHIPPING_TABLE_TEXT_DESCRIPTION' => 'Versandkosten nach Preis/Gewicht',
	'MODULE_SHIPPING_TABLE_TEXT_TITLE' => 'Versandkosten nach Preis/Gewicht',
	'MODULE_SHIPPING_TABLE_TEXT_WAY' => 'Standard',
	'MODULE_SHIPPING_TABLE_TEXT_WEIGHT' => 'Gewicht',
	'MODULE_SHIPPING_TABLE_UNDEFINED_RATE' => 'Die Versandkosten können im Moment nicht errechnet werden.',
	'MODULE_SHIPPING_TABLE_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, wird diese Versandmethode ausschließlich für diese Zone angewendet',
	'MODULE_SHIPPING_TABLE_ZONE_TITLE' => 'Versandzone'
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/table.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	table.lang.inc.php 2018-04-09 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_SHIPPING_TABLE_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, in welche ein Versand möglich sein soll. (z.B. AT,DE (lasse dieses Feld leer, wenn du alle Zonen erlauben willst))',
	'MODULE_SHIPPING_TABLE_ALLOWED_TITLE' => 'Erlaubte Versandzonen',
	'MODULE_SHIPPING_TABLE_COST_DESC' => 'Die Versandkosten basieren auf Gesamtkosten oder Gesamtgewicht der bestellten Waren. Beispiel: 25:5.50,50:8.50,etc.. Bis 25 werden 5.50 verrechnet, darüber bis 50 werden 8.50 verrechnet, etc',
	'MODULE_SHIPPING_TABLE_COST_TITLE' => 'Versandkosten',
	'MODULE_SHIPPING_TABLE_HANDLING_DESC' => 'Handling Gebühr für diese Versandmethode',
	'MODULE_SHIPPING_TABLE_HANDLING_TITLE' => 'Handling Gebühr',
	'MODULE_SHIPPING_TABLE_MODE_DESC' => 'Die Versandkosten basieren auf Gesamtkosten oder Gesamtgewicht der bestellten Waren.',
	'MODULE_SHIPPING_TABLE_MODE_TITLE' => 'Versandkosten Methode',
	'MODULE_SHIPPING_TABLE_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige',
	'MODULE_SHIPPING_TABLE_SORT_ORDER_TITLE' => 'Sortierreihenfolge',
	'MODULE_SHIPPING_TABLE_STATUS_DESC' => 'Möchtest du Versandkosten nach Preis/Gewicht anbieten?',
	'MODULE_SHIPPING_TABLE_STATUS_TITLE' => 'Versandkosten nach Preis/Gewicht aktivieren',
	'MODULE_SHIPPING_TABLE_TAX_CLASS_DESC' => 'Folgende Steuerklasse an Versandkosten anwenden',
	'MODULE_SHIPPING_TABLE_TAX_CLASS_TITLE' => 'Steuerklasse',
	'MODULE_SHIPPING_TABLE_TEXT_AMOUNT' => 'Menge',
	'MODULE_SHIPPING_TABLE_TEXT_DESCRIPTION' => 'Versandkosten nach Preis/Gewicht',
	'MODULE_SHIPPING_TABLE_TEXT_TITLE' => 'Versandkosten nach Preis/Gewicht',
	'MODULE_SHIPPING_TABLE_TEXT_WAY' => 'Standard',
	'MODULE_SHIPPING_TABLE_TEXT_WEIGHT' => 'Gewicht',
	'MODULE_SHIPPING_TABLE_UNDEFINED_RATE' => 'Die Versandkosten können im Moment nicht errechnet werden.',
	'MODULE_SHIPPING_TABLE_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, wird diese Versandmethode ausschließlich für diese Zone angewendet',
	'MODULE_SHIPPING_TABLE_ZONE_TITLE' => 'Versandzone'
);
